Token of the Video Output whose Layout is requested Current layout of the video output. Token of the Video Output whose Layout shall be changed Layout to be set Token of the Video Output whose options are requested The LayoutOptions describe the fixed and predefined layouts of a device. If the device does not offer fixed layouts and allows setting the layout free this element is empty. decoding and encoding capabilities of the device Reference Token of the Video Output whose Pane Configurations are requested Contains a list of defined Panes of the specified VideoOutput. Each VideoOutput has at least one PaneConfiguration. Reference Token of the Video Output the requested pane belongs to Reference Token of the Pane whose Configuration is requested returns the configuration of the requested pane. Token of the video output whose panes to set. Pane Configuration to be set. Token of the video output whose panes to set. Pane Configuration to be set. Token of the video output where the pane shall be created. Configuration of the pane to be created. Token of the video output where the pane shall be deleted. Token of the pane to be deleted. Return the current layout of a video output. The Layout assigns a pane configuration to a certain area of the display. The layout settings directly affect a specific video output. The layout consists of a list of PaneConfigurations and their associated display areas. Change the layout of a display (e.g. change from single view to split screen view).The Layout assigns a pane configuration to a certain area of the display. The layout settings directly affect a specific video output. The layout consists of a list of PaneConfigurations and their associated display areas. The Display Options contain the supported layouts (LayoutOptions) and the decoding and encoding capabilities (CodingCapabilities) of the device. The GetDisplayOptions command returns both, Layout and Coding Capabilities, of a VideoOutput. List all currently defined panes of a device for a specified video output (regardless if this pane is visible at a moment). A Pane is a display area on the monitor that is attached to a video output. A pane has a PaneConfiguration that describes which entities are associated with the pane. A client has to configure the pane according to the connection to be established by setting the AudioOutput and/or AudioSourceToken. If a Token is not set, the corresponding session will not be established. Retrieve the pane configuration for a pane token. Modify one or more configurations of the specified video output. This method will only modify the provided configurations and leave the others unchanged. Use DeletePaneConfiguration to remove pane configurations. This command changes the configuration of the specified pane (tbd) Create a new pane configuration describing the streaming and coding settings for a display area.
This optional method is only supported by devices that signal support of dynamic pane creation via their capabilities. Delete a pane configuration. A service must respond with an error if the pane configuration is in use by the current layout.
This optional method is only supported by devices that signal support of dynamic pane creation via their capabilities.